parser

package
v0.0.0-...-129e209 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2023 License: ISC Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ALF

type ALF struct {
	Title  string
	Author string
	Names  []string
	Artist string
	Album  string
	Notes  []string
}

ALF contains a structure equivalent to the Aurora Lyrics Format specification.

type Parser

type Parser struct {
	// contains filtered or unexported fields
}

Parser implements a source code file parser in ALF.

func New

func New(r io.Reader) *Parser

New creates and initializes a new `Parser` structure.

func (*Parser) Decode

func (p *Parser) Decode() (ALF, error)

Decode parses and returns an `ALF` structure with the parsed source code.

Jump to